@@ -283,7 +283,7 @@ void kweather::timeout(){
 
 int kweather::widthForHeight(int h) const
 {
-	kdDebug(12004) << "widthForHeight " << h << endl;
+	//kdDebug(12004) << "widthForHeight " << h << endl;
 	dockWidget->setOrientation(Horizontal);
 	int w = dockWidget->widthForHeight(h);
 	return w;
